import { useState, useContext } from 'react'
import TrainingHint from './TrainingHint'
import theme from '../../styles/theme'
import { TrainingContext } from '../../../pages/_app'

const TrainingArchive = () => {
  const trainingsPerPage = 4
  const [state, setState] = useState(0)
  const trainingsList = useContext(TrainingContext)

  const count = trainingsList.length
  const pages = []

  for (let index = 0; index < count / trainingsPerPage; index++) {
    pages.push(index)
  }

  return (
    <section className='training-archive'>
      <h2>Training Archive</h2>
      <ul>
        {trainingsList.map((training, index) => (
          <TrainingHint key={index} index={index} training={training.trainings[0]} />
        ))}
      </ul>
      {pages.map((index) => (
        <button
          key={index}
          onClick={() => setState(index)}
          className={index === state ? 'active' : undefined}
        >
          {index + 1}
        </button>
      ))}

      <style jsx>{`
        section {
          margin: 1.5em 1em;
        }
        ul {
          display: grid;
          grid-template-columns: 1fr;
          list-style: none;
          margin: 1.2em 0;
          padding: 0;
        }
        ul :global(a) {
          text-decoration: none;
          color: ${theme.colors.darkblue};
        }
        button {
          display: inline;
          border: none;
          padding: 0.3em 0.6em;
          margin: 0 0.3em;
          background-color: transparent;
          color: ${theme.colors.darkblue};
          border-radius: 6px;
          cursor: pointer;
        }
        button:hover {
          background-color: ${theme.colors.darkblue}22;
        }
        button.active {
          background-color: ${theme.colors.darkblue};
          color: ${theme.colors.offWhite};
        }
        @media (min-width: 480px) {
          ul {
            grid-template-columns: 1fr 1fr;
          }
        }
        @media (min-width: 1024px) {
          ul {
            grid-template-columns: repeat(4, 1fr);
          }
        }
      `}</style>
    </section>
  )
}

export default TrainingArchive
