import {
  Training,
  Block,
  Exercise,
  BlockInstance,
  ExerciseInstance,
} from "../gql";

export interface ITraining {
  id: string;
  title: string;
  type: {
    id: string;
    name: string;
    description: string;
  };
  createdAt: string;
  trainingDate: string;
  location: string;
  registrations: string[];
  attendance: number;
  ratings: IRating[];
  published: boolean;
  blocks: IBlock[];
}

export interface IBlock {
  id: string;
  sequence?: number;
  title?: string;
  comment?: string;
  description?: string;
  duration?: number;
  repetitions?: number;
  rest?: number;
  format?: IFormat;
  blocks?: IBlock[];
  exercises?: IExercise[];
  video?: string;
}

export interface IFormat {}

export interface IExercise {
  id: string;
  name: string;
  description: string;
  repetitions: number;
  videos: string[];
  pictures: string[];
  targets: string[];
  baseExercise: {
    id: string;
    name: string;
  };
}

export interface IRating {
  value: number;
}

export type TTraining = Pick<Training, "id" | "type"> &
  Partial<Omit<Training, "id" | "type">>;
export type TBlockInstance = Pick<BlockInstance, "id" | "block" | "order"> &
  Partial<Omit<BlockInstance, "id" | "block" | "order">>;
export type TBlock = Pick<
  Block,
  | "id"
  | "title"
  | "exercises"
  | "videos"
  | "blocks"
  | "tracks"
  | "pictures"
  | "format"
> &
  Partial<
    Omit<
      Block,
      | "id"
      | "title"
      | "exercises"
      | "videos"
      | "blocks"
      | "tracks"
      | "pictures"
      | "format"
    >
  >;
export type TExerciseInstance = Pick<ExerciseInstance, "id" | "exercise"> &
  Partial<Omit<ExerciseInstance, "id" | "exercise">>;
export type TExercise = Pick<
  Exercise,
  "id" | "name" | "pictures" | "videos" | "targets" | "baseExercise"
> &
  Partial<
    Omit<
      Exercise,
      "id" | "name" | "pictures" | "videos" | "targets" | "baseExercise"
    >
  >;
export type TRating = { value: number };
